@@ -1,7 +1,7 @@
 STATION_CODE = {
     "수서": "0551",
     "동탄": "0552",
-    "지제": "0553",
+    "평택지제": "0553",
     "천안아산": "0502",
     "오송": "0297",
     "대전": "0010",
