@@ -2,7 +2,6 @@ from .constants import STATION_NAME, TRAIN_NAME
 
 
 class SRTTicket:
-
     SEAT_TYPE = {"1": "일반실", "2": "특실"}
 
     PASSENGER_TYPE = {
@@ -66,6 +65,7 @@ class SRTReservation:
         self.payment_date = pay["iseLmtDt"]
         self.payment_time = pay["iseLmtTm"]
 
+        self.paid = pay["stlFlg"] == "Y"  # 결제 여부
         self._tickets = tickets
 
     def __str__(self):
@@ -80,8 +80,7 @@ class SRTReservation:
             "{month}월 {day}일, "
             "{dep}~{arr}"
             "({dep_hour}:{dep_min}~{arr_hour}:{arr_min}) "
-            "{cost}원({seats}석), "
-            "구입기한 {pay_month}월 {pay_day}일 {pay_hour}:{pay_min}"
+            "{cost}원({seats}석)"
         ).format(
             name=self.train_name,
             month=self.dep_date[4:6],
@@ -94,12 +93,14 @@ class SRTReservation:
             arr_min=self.arr_time[2:4],
             cost=self.total_cost,
             seats=self.seat_count,
-            pay_month=self.payment_date[4:6],
-            pay_day=self.payment_date[6:8],
-            pay_hour=self.payment_time[0:2],
-            pay_min=self.payment_time[2:4],
         )
-
+        if not self.paid:
+            d += (", 구입기한 {pay_month}월 {pay_day}일 {pay_hour}:{pay_min}").format(
+                pay_month=self.payment_date[4:6],
+                pay_day=self.payment_date[6:8],
+                pay_hour=self.payment_time[0:2],
+                pay_min=self.payment_time[2:4],
+            )
         return d
 
     @property
